@@ -20,13 +20,12 @@ OC.L10N.register(
     "Display name" : "Vertoonnaam",
     "Last modified" : "Laas gewysig",
     "Save" : "Bewaar",
-    "Description" : "Beskrywing",
+    "Edit" : "Wysig",
     "Cancel" : "Kanselleer",
     "Invalid image" : "Ongeldige beeld",
     "Name" : "Naam",
     "Title" : "Titel",
     "Company" : "Maatskappy",
-    "Edit" : "Wysig",
     "Search contacts …" : "Soek kontakte …",
     "Pending" : "Hangend",
     "Select Date" : "Kies Datum",
@@ -43,6 +42,7 @@ OC.L10N.register(
     "Contact" : "Kontak",
     "Admin" : "Admin",
     "Owner" : "Eienaar",
+    "Privacy" : "Privaatheid",
     "Detailed name" : "Gedetailleerde naam",
     "Additional names" : "Addisionele name",
     "Prefix" : "Voorvoegsel",
@@ -95,6 +95,6 @@ OC.L10N.register(
     "Female" : "Vroulik",
     "Male" : "Manlik",
     "Unknown" : "Onbekend",
-    "Manager" : "Bestuurder"
+    "Description" : "Beskrywing"
 },
 "nplurals=2; plural=(n != 1);");
