@@ -18,14 +18,13 @@ OC.L10N.register(
     "Last name" : "Apellido",
     "Display name" : "Nombre a desplegar",
     "Last modified" : "Última modificación",
-    "Password protection" : "Protección con contraseña",
     "Save" : "Guardar",
-    "Description" : "Descripción",
     "Cancel" : "Cancelar",
     "Invalid image" : "Imagen inválida",
     "Address book" : "Libreta de direcciones",
     "Name" : "Nombre",
     "Title" : "Título",
+    "Groups" : "Grupos",
     "Search contacts …" : "Buscar contactos ...",
     "No results" : "No hay resultados",
     "Pending" : "Pendiente",
@@ -42,7 +41,7 @@ OC.L10N.register(
     "Moderator" : "Moderador",
     "Admin" : "Admin",
     "Owner" : "Dueño",
-    "Groups" : "Grupos",
+    "Privacy" : "Privacidad",
     "Detailed name" : "Nombre detallado",
     "Additional names" : "Nombres adicionales",
     "Prefix" : "Prefijo",
@@ -93,6 +92,8 @@ OC.L10N.register(
     "Gender" : "Género",
     "Female" : "Femenino",
     "Male" : "Masculino",
-    "Unknown" : "Desconocido"
+    "Unknown" : "Desconocido",
+    "Password protection" : "Protección con contraseña",
+    "Description" : "Descripción"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
