@@ -6,30 +6,28 @@ OC.L10N.register(
     "Contacts" : "Contactes",
     "Loading …" : "Cargament…",
     "General settings" : "Paramètres generals",
-    "Send email" : "Enviar email",
-    "Circles" : "Cercles",
-    "Download" : "Telecargar",
     "Rename" : "Renomenar",
-    "Enabled" : "Activada",
+    "Send email" : "Enviar email",
     "Delete" : "Suprimir",
     "Copy link" : "Copiar lo ligam",
+    "Download" : "Telecargar",
     "can edit" : "pòt modificar",
+    "Add" : "Ajustar",
     "First name" : "Prenom",
     "Last name" : "Nom",
     "Display name" : "Nom afichat",
-    "Password protection" : "Proteccion per senhal",
     "Save" : "Enregistrar",
-    "Description" : "Descripcion",
     "Cancel" : "Anullar",
     "Invalid image" : "Imatge invalid",
     "Name" : "Nom",
     "Title" : "Títol",
     "Company" : "Entrepresa",
-    "New contact" : "Contacte novèl",
+    "Groups" : "Gropes",
     "Search contacts …" : "Cercar pels contactes…",
     "No results" : "Cap de resultat",
     "Pending" : "En espèra",
     "None" : "Pas cap",
+    "New contact" : "Contacte novèl",
     "Close" : "Tampar",
     "Import" : "Importar",
     "Not grouped" : "Pas gropats",
@@ -40,8 +38,6 @@ OC.L10N.register(
     "Contact" : "Contacte",
     "Admin" : "Admin",
     "Owner" : "Owner",
-    "Visibility" : "Visibilitat",
-    "Users" : "Utilizaires",
     "Additional names" : "Noms suplementaris",
     "Nickname" : "Escais",
     "Notes" : "Nòtas",
@@ -66,6 +62,10 @@ OC.L10N.register(
     "Voice" : "Votz",
     "Relative" : "Relatiu",
     "Unknown" : "Desconegut",
-    "Spoken languages" : "Lengas parladas"
+    "Spoken languages" : "Lengas parladas",
+    "Password protection" : "Proteccion per senhal",
+    "Description" : "Descripcion",
+    "Settings" : "Settings",
+    "Visibility" : "Visibilitat"
 },
 "nplurals=2; plural=(n > 1);");
