@@ -88,17 +88,16 @@ OC.L10N.register(
     "Sort by {sorting}" : "以 {sorting} 排序",
     "Manages" : "管理",
     "Oversees" : "监督",
+    "An error happened during the config change" : "更改配置时发生一个错误",
     "Enforce password protection on files shared to this team" : "对与此团队共享的文件强制实施密码保护",
     "Use a unique password for all shares to this team" : "为此团队的全部共享使用唯一密码",
     "Unique password …" : "独立密码 ...",
     "Save" : "保存",
     "Change unique password" : "修改独立密码",
     "Failed to save password. Please try again later." : "保存密码失败，请稍后重试。",
-    "An error happened during the config change" : "更改配置时发生一个错误",
     "There is no description for this team" : "此团队没有描述",
     "Enter a description for the team" : "输入团队的描述",
-    "An error happened during description sync" : "描述同步期间发生一个错误",
-    "An error happened during name sync" : "名称同步期间发生了一个错误",
+    "An error happened while saving {fields}" : "保存 {fields} 时出错",
     "Team name" : "团队名称",
     "Team owner" : "团队所有者",
     "Edit" : "编辑",
@@ -154,8 +153,15 @@ OC.L10N.register(
     "Calendar events with you" : "与您分享的日历事件",
     "Deck cards with you" : "与您分享的卡片",
     "No shared items with this contact" : "与该联系人无共享项目",
+    "Confirm merging contacts" : "确认合并联系人",
+    "The selected contacts have conflicting information. Choose which information to keep" : "所选联系人的信息存在冲突。请选择要保留的信息",
+    "Contacts can be merged" : "联系人可以合并",
+    "Groups" : "群组",
+    "Select groups to add the merged contact to" : "选择要添加合并联系人的组",
+    "Merge contacts" : "合并联系人",
     "_Delete {number} contact_::_Delete {number} contacts_" : ["删除 {number} 位联系人"],
     "Please select at least one editable contact to delete" : "请至少选择一个可编辑的联系人进行删除",
+    "Please select two editable contacts to merge" : "请选择两个可编辑的联系人进行合并",
     "Are you sure you want to proceed?" : "是否确定要继续？",
     "Search contacts …" : "搜索联系人 ...",
     "Unselect {number}" : "取消选择 {number}",
@@ -163,7 +169,9 @@ OC.L10N.register(
     "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "请注意，您只能将可写通讯录中的联系人添加到联系人组。无法添加只读通讯录（如系统通讯录）中的联系人。",
     "Remove {type}" : "移除 {type}",
     "Add to group" : "添加到群组",
+    "Invite members to team" : "邀请成员加入团队",
     "Search {types}" : "搜索 {types}",
+    "Add guest" : "添加访客",
     "Search for people to add" : "搜索要添加的人",
     "No results" : "无结果",
     "Add {type}" : "添加  {type}",
@@ -253,7 +261,6 @@ OC.L10N.register(
     "users" : "用户",
     "Users" : "用户",
     "groups" : "群组",
-    "Groups" : "群组",
     "teams" : "团队",
     "email addresses" : "电子邮件地址",
     "Email addresses" : "电子邮件地址",
@@ -324,6 +331,8 @@ OC.L10N.register(
     "Unable to delete team {circleId}" : "无法删除团队 {circleId}",
     "Unable to delete contact" : "无法删除联系人",
     "Password protection" : "密码保护",
+    "An error happened during description sync" : "描述同步期间发生一个错误",
+    "An error happened during name sync" : "名称同步期间发生了一个错误",
     "Team owned by {owner}" : "{owner} 拥有的团队",
     "Team settings" : "团队设置",
     "Description" : "描述",
