@@ -88,17 +88,16 @@ OC.L10N.register(
     "Sort by {sorting}" : "按 {sorting} 排序",
     "Manages" : "管理",
     "Oversees" : "監督",
+    "An error happened during the config change" : "變更設定時發生錯誤",
     "Enforce password protection on files shared to this team" : "對分享到此團隊的檔案加上密碼保護",
     "Use a unique password for all shares to this team" : "對此團隊的所有分享使用獨一無二的密碼",
     "Unique password …" : "獨一無二的密碼……",
     "Save" : "儲存",
     "Change unique password" : "變更獨一無二的密碼",
     "Failed to save password. Please try again later." : "儲存密碼失敗。請稍後再試。",
-    "An error happened during the config change" : "變更設定時發生錯誤",
     "There is no description for this team" : "此團隊沒有描述",
     "Enter a description for the team" : "輸入團隊的描述",
-    "An error happened during description sync" : "描述同步時發生錯誤",
-    "An error happened during name sync" : "名稱同步時發生錯誤",
+    "An error happened while saving {fields}" : "儲存 {fields} 時發生錯誤",
     "Team name" : "團隊名稱",
     "Team owner" : "團隊擁有者",
     "Edit" : "編輯",
@@ -154,8 +153,15 @@ OC.L10N.register(
     "Calendar events with you" : "有您的日曆事件",
     "Deck cards with you" : "有您的 Deck 卡片",
     "No shared items with this contact" : "沒有與該聯絡人分享的項目",
+    "Confirm merging contacts" : "確認合併聯絡人",
+    "The selected contacts have conflicting information. Choose which information to keep" : "選定的聯絡人有互相衝突的資訊。請選擇要保留的資訊",
+    "Contacts can be merged" : "可以合併聯絡人",
+    "Groups" : "群組",
+    "Select groups to add the merged contact to" : "選取要新增合併聯絡人的群組",
+    "Merge contacts" : "合併聯絡人",
     "_Delete {number} contact_::_Delete {number} contacts_" : ["刪除 {number} 個聯絡人"],
     "Please select at least one editable contact to delete" : "請選取至少一個可編輯的聯絡人來刪除",
+    "Please select two editable contacts to merge" : "請選取兩個可編輯的聯絡人進行合併",
     "Are you sure you want to proceed?" : "您想要繼續嗎？",
     "Search contacts …" : "搜尋聯絡人……",
     "Unselect {number}" : "取消選取 {number}",
@@ -163,7 +169,9 @@ OC.L10N.register(
     "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "請注意，您只能將可寫通訊錄中的聯絡人新增至聯絡人群組。來自唯讀通訊錄（例如系統通訊錄）的聯絡人則無法新增。",
     "Remove {type}" : "移除 {type}",
     "Add to group" : "新增至群組",
+    "Invite members to team" : "邀請成員加入團隊",
     "Search {types}" : "搜尋 {types}",
+    "Add guest" : "新增訪客",
     "Search for people to add" : "搜尋要新增的人",
     "No results" : "沒有結果",
     "Add {type}" : "新增 {type}",
@@ -253,7 +261,6 @@ OC.L10N.register(
     "users" : "使用者",
     "Users" : "使用者",
     "groups" : "群組",
-    "Groups" : "群組",
     "teams" : "團隊",
     "email addresses" : "電子郵件地址",
     "Email addresses" : "電子郵件地址",
@@ -324,6 +331,8 @@ OC.L10N.register(
     "Unable to delete team {circleId}" : "無法刪除團隊 {circleId}",
     "Unable to delete contact" : "無法刪除聯絡人",
     "Password protection" : "密碼保護",
+    "An error happened during description sync" : "描述同步時發生錯誤",
+    "An error happened during name sync" : "名稱同步時發生錯誤",
     "Team owned by {owner}" : "{owner} 擁有的團隊",
     "Team settings" : "團隊設定",
     "Description" : "描述",
